summaryrefslogtreecommitdiffstats
path: root/experimental/tqtinterface/qt4/src/3rdparty/sqlite/btree.c
diff options
context:
space:
mode:
Diffstat (limited to 'experimental/tqtinterface/qt4/src/3rdparty/sqlite/btree.c')
-rw-r--r--experimental/tqtinterface/qt4/src/3rdparty/sqlite/btree.c46
1 files changed, 23 insertions, 23 deletions
diff --git a/experimental/tqtinterface/qt4/src/3rdparty/sqlite/btree.c b/experimental/tqtinterface/qt4/src/3rdparty/sqlite/btree.c
index f3b92c62f..c7143e095 100644
--- a/experimental/tqtinterface/qt4/src/3rdparty/sqlite/btree.c
+++ b/experimental/tqtinterface/qt4/src/3rdparty/sqlite/btree.c
@@ -5,7 +5,7 @@
** a legal notice, here is a blessing:
**
** May you do good and not evil.
-** May you tqfind forgiveness for yourself and forgive others.
+** May you find forgiveness for yourself and forgive others.
** May you share freely, never taking more than you give.
**
*************************************************************************
@@ -18,7 +18,7 @@
** "Sorting And Searching", pages 473-480. Addison-Wesley
** Publishing Company, Reading, Massachusetts.
**
** The basic idea is that each page of the file tqcontains N database
** entries and N+1 pointers to subpages.
**
** ----------------------------------------------------------------
@@ -41,13 +41,13 @@
** database page. If the payload is larger than MX_LOCAL_PAYLOAD bytes
** then surplus bytes are stored on overflow pages. The payload for an
** entry and the preceding pointer are combined to form a "Cell". Each
** page has a small header which tqcontains the Ptr(N+1) pointer.
**
** The first page of the file tqcontains a magic string used to verify that
** the file really is a valid BTree database, a pointer to a list of unused
** pages in the file, and some meta information. The root of the first
** BTree begins on page 2 of the file. (Pages are numbered beginning with
** 1, not 0.) Thus a minimum database tqcontains 2 pages.
*/
#include "sqliteInt.h"
#include "pager.h"
@@ -110,7 +110,7 @@ typedef struct FreelistInfo FreelistInfo;
** STQLite database in order to identify the file as a real database.
*/
static const char zMagicHeader[] =
- "** This file tqcontains an STQLite 2.1 database **";
+ "** This file contains an STQLite 2.1 database **";
#define MAGIC_SIZE (sizeof(zMagicHeader))
/*
@@ -127,13 +127,13 @@ static const char zMagicHeader[] =
#define MAGIC 0xdae37528
/*
** The first page of the database file tqcontains a magic header string
** to identify the file as an STQLite database file. It also tqcontains
** a pointer to the first free page of the file. Page 2 tqcontains the
** root of the principle BTree. The file might contain other BTrees
** rooted on pages above 2.
**
** The first page also tqcontains STQLITE_N_BTREE_META integers that
** can be used by higher-level routines.
**
** Remember that pages are numbered beginning with 1. (See pager.c
@@ -161,9 +161,9 @@ struct PageOne {
** is the index into MemPage.u.aDisk[] of the first cell on the page. The
** Cells are kept in sorted order.
**
** A Cell tqcontains all information about a database entry and a pointer
** to a child page that tqcontains other entries less than itself. In
** other words, the i-th Cell tqcontains both Ptr(i) and Key(i). The
** right-most pointer of the page is contained in PageHdr.rightChild.
*/
struct PageHdr {
@@ -220,7 +220,7 @@ struct CellHdr {
/*
** The maximum amount of payload (in bytes) that can be stored locally for
** a database entry. If the entry tqcontains more data than this, the
** extra goes onto overflow pages.
**
** This number is chosen so that at least 4 cells will fit on every page.
@@ -282,7 +282,7 @@ struct OverflowPage {
/*
** The PageOne.freeList field points to a linked list of overflow pages
** hold information about free pages. The aPayload section of each
** overflow page tqcontains an instance of the following structure. The
** aFree[] array holds the page number of nFree unused pages in the disk
** file.
*/
@@ -293,7 +293,7 @@ struct FreelistInfo {
/*
** For every page in the database file, an instance of the following structure
** is stored in memory. The u.aDisk[] array tqcontains the raw bits read from
** the disk. The rest is auxiliary information held in memory only. The
** auxiliary info is only valid for regular database pages - it is not
** used for overflow pages and pages on the freelist.
@@ -304,7 +304,7 @@ struct FreelistInfo {
** than in linear time which would be needed if we had to walk the linked
** list on every access.
**
** Note that apCell[] tqcontains enough space to hold up to two more Cells
** than can possibly fit on one page. In the steady state, every apCell[]
** points to memory inside u.aDisk[]. But in the middle of an insert
** operation, some apCell[] entries may temporarily point to data space
@@ -366,7 +366,7 @@ struct BtCursor {
BtCursor *pNext, *pPrev; /* Forms a linked list of all cursors */
BtCursor *pShared; /* Loop of cursors with the same root page */
Pgno pgnoRoot; /* The root page of this tree */
- MemPage *pPage; /* Page that tqcontains the entry */
+ MemPage *pPage; /* Page that contains the entry */
int idx; /* Index of the entry in pPage->apCell[] */
u8 wrFlag; /* True if writable */
u8 eSkip; /* Determines if next step operation is a no-op */
@@ -462,7 +462,7 @@ static void defragmentPage(Btree *pBt, MemPage *pPage){
** the new allocation. Or return 0 if there is not enough free
** space on the page to satisfy the allocation request.
**
** If the page tqcontains nBytes of free space but does not contain
** nBytes of contiguous free space, then this routine automatically
** calls defragementPage() to consolidate all free space before
** allocating the new chunk.
@@ -1411,7 +1411,7 @@ static int moveToChild(BtCursor *pCur, int newPgno){
/*
** Move the cursor up to the tqparent page.
**
** pCur->idx is set to the cell index that tqcontains the pointer
** to the page we are coming from. If we are coming from the
** right-most child page then pCur->idx is set to one more than
** the largest cell index.
@@ -1498,8 +1498,8 @@ static int moveToLeftmost(BtCursor *pCur){
** Move the cursor down to the right-most leaf entry beneath the
** page to which it is currently pointing. Notice the difference
** between moveToLeftmost() and moveToRightmost(). moveToLeftmost()
-** tqfinds the left-most entry beneath the *entry* whereas moveToRightmost()
-** tqfinds the right-most entry beneath the *page*.
+** finds the left-most entry beneath the *entry* whereas moveToRightmost()
+** finds the right-most entry beneath the *page*.
*/
static int moveToRightmost(BtCursor *pCur){
Pgno pgno;
@@ -2313,7 +2313,7 @@ static int balance(Btree *pBt, MemPage *pPage, BtCursor *pCur){
/*
** Find sibling pages to pPage and the Cells in pParent that divide
- ** the siblings. An attempt is made to tqfind NN siblings on either
+ ** the siblings. An attempt is made to find NN siblings on either
** side of pPage. More siblings are taken from one side, however, if
** pPage there are fewer than NN siblings on the other side. If pParent
** has NB or fewer tqchildren then all tqchildren of pParent are taken.
@@ -18,7 +18,7 @@
** Publishing Company, Reading, Massachusetts.
**
-** The basic idea is that each page of the file tqcontains N database
+** The basic idea is that each page of the file contains N database
** entries and N+1 pointers to subpages.
**
@@ -41,13 +41,13 @@
** then surplus bytes are stored on overflow pages. The payload for an
** entry and the preceding pointer are combined to form a "Cell". Each
-** page has a small header which tqcontains the Ptr(N+1) pointer.
+** page has a small header which contains the Ptr(N+1) pointer.
**
@@ -41,13 +41,13 @@
**
-** The first page of the file tqcontains a magic string used to verify that
+** The first page of the file contains a magic string used to verify that
** the file really is a valid BTree database, a pointer to a list of unused
** pages in the file, and some meta information. The root of the first
@@ -41,13 +41,13 @@
** pages in the file, and some meta information. The root of the first
** BTree begins on page 2 of the file. (Pages are numbered beginning with
-** 1, not 0.) Thus a minimum database tqcontains 2 pages.
+** 1, not 0.) Thus a minimum database contains 2 pages.
*/
#include "sqliteInt.h"
@@ -127,13 +127,13 @@ static const char zMagicHeader[] =
#define MAGIC 0xdae37528
/*
-** The first page of the database file tqcontains a magic header string
-** to identify the file as an STQLite database file. It also tqcontains
-** a pointer to the first free page of the file. Page 2 tqcontains the
+** The first page of the database file contains a magic header string
+** to identify the file as an STQLite database file. It also contains
+** a pointer to the first free page of the file. Page 2 contains the
** root of the principle BTree. The file might contain other BTrees
** rooted on pages above 2.
@@ -127,13 +127,13 @@ static const char zMagicHeader[] =
** rooted on pages above 2.
**
-** The first page also tqcontains STQLITE_N_BTREE_META integers that
+** The first page also contains STQLITE_N_BTREE_META integers that
** can be used by higher-level routines.
**
@@ -161,9 +161,9 @@ struct PageOne {
** Cells are kept in sorted order.
**
-** A Cell tqcontains all information about a database entry and a pointer
-** to a child page that tqcontains other entries less than itself. In
-** other words, the i-th Cell tqcontains both Ptr(i) and Key(i). The
+** A Cell contains all information about a database entry and a pointer
+** to a child page that contains other entries less than itself. In
+** other words, the i-th Cell contains both Ptr(i) and Key(i). The
** right-most pointer of the page is contained in PageHdr.rightChild.
*/
@@ -220,7 +220,7 @@ struct CellHdr {
/*
** The maximum amount of payload (in bytes) that can be stored locally for
-** a database entry. If the entry tqcontains more data than this, the
+** a database entry. If the entry contains more data than this, the
** extra goes onto overflow pages.
**
@@ -282,7 +282,7 @@ struct OverflowPage {
** The PageOne.freeList field points to a linked list of overflow pages
** hold information about free pages. The aPayload section of each
-** overflow page tqcontains an instance of the following structure. The
+** overflow page contains an instance of the following structure. The
** aFree[] array holds the page number of nFree unused pages in the disk
** file.
@@ -293,7 +293,7 @@ struct FreelistInfo {
/*
** For every page in the database file, an instance of the following structure
-** is stored in memory. The u.aDisk[] array tqcontains the raw bits read from
+** is stored in memory. The u.aDisk[] array contains the raw bits read from
** the disk. The rest is auxiliary information held in memory only. The
** auxiliary info is only valid for regular database pages - it is not
@@ -304,7 +304,7 @@ struct FreelistInfo {
** list on every access.
**
-** Note that apCell[] tqcontains enough space to hold up to two more Cells
+** Note that apCell[] contains enough space to hold up to two more Cells
** than can possibly fit on one page. In the steady state, every apCell[]
** points to memory inside u.aDisk[]. But in the middle of an insert
@@ -462,7 +462,7 @@ static void defragmentPage(Btree *pBt, MemPage *pPage){
** space on the page to satisfy the allocation request.
**
-** If the page tqcontains nBytes of free space but does not contain
+** If the page contains nBytes of free space but does not contain
** nBytes of contiguous free space, then this routine automatically
** calls defragementPage() to consolidate all free space before
@@ -1411,7 +1411,7 @@ static int moveToChild(BtCursor *pCur, int newPgno){
** Move the cursor up to the tqparent page.
**
-** pCur->idx is set to the cell index that tqcontains the pointer
+** pCur->idx is set to the cell index that contains the pointer
** to the page we are coming from. If we are coming from the
** right-most child page then pCur->idx is set to one more than